==> google-cloud-spanner-6.37.0-sources.jar: com/google/cloud/spanner/SpannerApiFutures.java <==
/*
 * Copyright 2020 Google LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.google.cloud.spanner;

import com.google.api.core.ApiFuture;
import com.google.common.base.Preconditions;
import java.util.concurrent.CancellationException;
import java.util.concurrent.ExecutionException;

public class SpannerApiFutures {
  public static <T> T get(ApiFuture<T> future) throws SpannerException {
    return getOrNull(Preconditions.checkNotNull(future));
  }

  public static <T> T getOrNull(ApiFuture<T> future) throws SpannerException {
    try {
      return future == null ? null : future.get();
    } catch (ExecutionException e) {
      if (e.getCause() instanceof SpannerException) {
        throw (SpannerException) e.getCause();
      }
      throw SpannerExceptionFactory.newSpannerException(e.getCause());
    } catch (InterruptedException e) {
      throw SpannerExceptionFactory.propagateInterrupt(e);
    } catch (CancellationException e) {
      throw SpannerExceptionFactory.newSpannerExceptionForCancellation(null, e);
    }
  }
}

==> google-cloud-spanner-6.98.0-sources.jar: com/google/cloud/spanner/SpannerApiFutures.java <==
/*
 * Copyright 2020 Google LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.google.cloud.spanner;

import com.google.api.core.ApiFuture;
import com.google.common.base.Preconditions;
import java.util.concurrent.CancellationException;
import java.util.concurrent.ExecutionException;

public class SpannerApiFutures {
  public static <T> T get(ApiFuture<T> future) throws SpannerException {
    return getOrNull(Preconditions.checkNotNull(future));
  }

  public static <T> T getOrNull(ApiFuture<T> future) throws SpannerException {
    try {
      return future == null ? null : future.get();
    } catch (ExecutionException e) {
      if (e.getCause() instanceof SpannerException) {
        throw (SpannerException) e.getCause();
      }
      throw SpannerExceptionFactory.newSpannerException(e.getCause());
    } catch (InterruptedException e) {
      throw SpannerExceptionFactory.propagateInterrupt(e, null /*TODO: requestId*/);
    } catch (CancellationException e) {
      throw SpannerExceptionFactory.newSpannerExceptionForCancellation(
          null, e, null /*TODO: requestId*/);
    }
  }
}
